;; Generated package description from transient.el  -*- no-byte-compile: t -*-
(define-package "transient" "0.6.0" "Transient commands" '((emacs "26.1") (compat "29.1.4.4") (seq "2.24")) :commit "55d5d41b48d7f7bc1ecf1f90c012d7821dff5724" :authors '(("Jonas Bernoulli" . "jonas@bernoul.li")) :maintainer '("Jonas Bernoulli" . "jonas@bernoul.li") :keywords '("extensions") :url "https://github.com/magit/transient")
